//==============================================================================
//    入力チェック テンプレート
//    カスタムプロパティ取得関数
//
//        【 入力 】 formaParam                  : フォルマパラメータオブジェクト
//                   formaParam.loginGroupId     : ログイングループID
//                   formaParam.loginUserId      : ログインユーザID
//                   formaParam.applicationId    : アプリケーションID
//                   formaParam.applicationNo    : アプリケーション番号
//                   formaParam.applicationType  : アプリケーション種別
//                   formaParam.pageType         : アプリケーションページ種別
//                   formaParam.formId           : フォームID
//                   formaParam.insertId         : 登録ID
//                   sendParam                   : 送信パラメータオブジェクト
//
//        【返却値】 result.data                 : カスタムプロパティオブジェクト
//                   result.error                : エラーフラグ     [true:失敗/false:成功]
//                   result.errorMessage         : エラーメッセージ 
//
//
//
//==============================================================================

function getCustomProperties(formaParam, sendParam) {
    return { error: false, data: {} };
}

//==============================================================================
//    入力チェック テンプレート
//    ユーザバリデーション実行関数
//
//        【 入力 】 formaParam                  : フォルマパラメータオブジェクト
//                   formaParam.loginUserId      : ログインユーザID
//                   formaParam.applicationId    : アプリケーションID
//                   formaParam.applicationNo    : アプリケーション番号
//                   formaParam.applicationType  : アプリケーション種別
//                   formaParam.appPageType      : アプリケーションページ種別 
//                   formaParam.formId           : フォームID
//                   formaParam.insertId         : 登録ID
//                   sendParam                   : 送信パラメータオブジェクト
//                   resultObj                   : 処理結果返却オブジェクト
//
//        【返却値】 resultObj                   : 処理結果返却オブジェクト
//                   result.error                               : エラーフラグ     [true:入力チェックエラーあり/false:入力チェックエラーなし]
//                   result.systemError                         : システムエラーフラグ  [true:失敗/false:成功]
//                   result.errorMessageList                    : エラーメッセージ情報配列
//                   result.errorInfoList                       : エラー情報配列
//                   result.errorList[x].checkid                : 入力チェックID
//                   result.errorList[x].acceptErrorObj         : 返却オブジェクト
//                   result.errorList[x].acceptErrorObj.inputId : フィールド識別ID
//
//==============================================================================
function validate(formaParam, sendParam, resultObj) {

    if (sendParam["imfr_transition_mode"] === "tab_contents") {
        // 【タブ切替時】
        // 必須入力チェック、条件付き必須入力チェックは行いません。

    } else if (sendParam["imfr_transition_mode"] === "") {
        // 【処理ボタン押下時】

        // [tab-1] Radio の必須入力チェックを行います。
        // [tab-1] Radio の設定値を取得します。
        var radio = sendParam["imfr_other_form_param"]["radio"];
        if (radio === "") {
            // [tab-1] Radio が未入力の場合は、必須入力エラーとします。
            var errorMessage = "[tab-1] Radio is required.";
            ImFormaUtil.addValidationError(resultObj, errorMessage, "check1", []);
        }

        if (formaParam["temporaryFlag"] === "1") {
            // 【処理ボタン：一時保存 押下時】
            // 前述の[tab-1] Radio 必須入力のみを行い、条件付き必須入力チェックは行いません。

        } else if (formaParam["temporaryFlag"] === "0") {
            // 【処理ボタン：登録/更新 押下時】

            // [tab-1] Radio の設定値に合せた条件付き必須入力チェックを行います。
            if (radio === "1" && sendParam["text1"] === "") {
                // Type1 が選択されている場合、Text1 は必須入力です。
                var errorMessage = "Text1 is required.";
                ImFormaUtil.addValidationError(resultObj, errorMessage, "check2", ["text1"]);

            } else if (radio === "2" && sendParam["text2"] === "") {
                // Type2 が選択されている場合、Text2 は必須入力です。
                var errorMessage = "Text2 is required.";
                ImFormaUtil.addValidationError(resultObj, errorMessage, "check3", ["text2"]);
            }
        }
    }

    return resultObj;
}

//==============================================================================
//    入力チェック テンプレート
//    エラーメッセージ表示順序取得関数
//
//        【 入力 】 formaParam                     : フォルマパラメータオブジェクト
//                                                  
//                                                  
//        【返却値】 エラーメッセージを表示する順序で格納されたアイテムＩＤ・入力チェックＩＤの配列
//
//==============================================================================
function getErrorDisplayOrder(formaParam) {
    var arry = [];
    return arry;
}
